``Products.GenericSetup``
=========================

.. image:: https://travis-ci.org/zopefoundation/Products.GenericSetup.png?branch=master
        :target: https://travis-ci.org/zopefoundation/Products.GenericSetup

This product provides a mini-framework for expressing the configured
state of a Zope Site as a set of filesystem artifacts.  These artifacts
consist of declarative XML files, which spell out the configuration
settings for each "tool" in the site , and supporting scripts / templates,
in their "canonical" filesystem representations.

See ``docs/index.rst`` for full documentation.  This documentation can
also be found online:  http://packages.python.org/Products.GenericSetup/
